@@ -365,6 +365,10 @@ if (typeof ajax_helpers === 'undefined') {
                 alert(command.text);
             },
 
+            clipboard: function(command){
+                navigator.clipboard.writeText(command.text);
+            },
+
             upload_file: function (command) {
                 var file, file_data;
                 var index = command.index !== undefined ? command.index : 0;
@@ -392,7 +396,7 @@ if (typeof ajax_helpers === 'undefined') {
                     file_data = file;
                 }
                 form_data.ajax_modal_file = file_data;
-                ajax_helpers.send_form(null, form_data, null, command.options)
+                ajax_helpers.send_form(null, form_data, 0, command.options)
             }
         };
 
