@@ -13,7 +13,7 @@ def lib_include(context, *args, **kwargs):
     request = context.get('request')
     legacy = False
     if request:
-        user_agent = request.META['HTTP_USER_AGENT']
+        user_agent = request.META.get('HTTP_USER_AGENT', '')
         if 'Trident' in user_agent or 'MSIE' in user_agent:
             legacy = True
     include_str = ''
@@ -36,10 +36,12 @@ def determine_css_class(bootstrap_style, css_class):
 
 
 @register.simple_tag
-def button_javascript(button_name, url_name=None, url_args=None, **kwargs):
+def button_javascript(button_name, url_name=None, url_args=None, blob=False, **kwargs):
     json_data = {'data': dict(button=button_name, **kwargs)}
     if url_name:
         json_data['url'] = reverse(url_name, args=url_args)
+    if blob:
+        json_data['response_type'] = 'blob'
     return mark_safe(f'ajax_helpers.post_json({json.dumps(json_data)})')
 
 
@@ -62,11 +64,15 @@ def send_form_button(text, form_id, bootstrap_style='primary', css_class=None, *
 
 
 @register.inclusion_tag('ajax_helpers/upload_file.html')
-def upload_file(text='Upload File', bootstrap_style='primary', css_class=None):
+def upload_file(text='Upload File', bootstrap_style='primary', css_class=None, drag_drop=None, width=None, height=None, progress=False):
     return {
         'id': random_string(),
         'text': text,
         'css_class': determine_css_class(bootstrap_style, css_class),
+        'drag_drop': drag_drop,
+        'width': width,
+        'height': height,
+        'progress': progress,
     }
 
 
